#ifndef ConnectionAttributes_h
#define ConnectionAttributes_h

// $Id: ConnectionAttributes.h,v 1.8 2013/04/29 18:27:14 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/


#include "Counter.h"
#include "TunnelAttributes.h"

#include <QDomDocument>
#include <QDomElement>
#include <QStringList>
#include <QList>

//! tunnel attributes
class ConnectionAttributes: public Counter
{

    public:

    typedef QList<ConnectionAttributes> List;
    typedef QListIterator<ConnectionAttributes> ListIterator;

    //! constructor
    ConnectionAttributes( void );

    //! constructor
    ConnectionAttributes( const QDomElement& );

    //! dom element
    QDomElement domElement( QDomDocument& ) const;

    //! equal to operator
    bool operator == (const ConnectionAttributes& attributes) const
    {
        return
            name() == attributes.name() &&
            host() == attributes.host() &&
            user() == attributes.user() &&
            options() == attributes.options() &&
            tunnelAttributes() == attributes.tunnelAttributes();
    }

    //! true if connection settings have changed
    bool connectionSettingsChanged( const ConnectionAttributes& attributes ) const
    {
        return
            host() != attributes.host() ||
            user() != attributes.user() ||
            tunnelAttributes() != attributes.tunnelAttributes() ||
            options() != attributes.options();
    }

    //! less than operator
    bool operator < ( const ConnectionAttributes& attributes ) const
    { return name_ < attributes.name_; }

    //! errors
    QStringList errors( void ) const;

    //! validity
    bool isValid( void ) const;

    //! name
    QString name( void ) const
    { return name_; }

    //! name
    ConnectionAttributes& setName( const QString& name )
    {
        name_ = name;
        return *this;
    }

    //! host
    QString host( void ) const
    { return host_; }

    //! host
    ConnectionAttributes& setHost( const QString& host )
    {
        host_ = host;
        return *this;
    }

    //! user
    QString user( void ) const
    {  return user_; }

    //! user
    ConnectionAttributes& setUser( const QString& user )
    {
        user_ = user;
        return *this;
    }

    //! options
    QString options( void ) const
    {  return options_; }

    //! options
    ConnectionAttributes& setOptions( const QString& options )
    {
        options_ = options;
        return *this;
    }

    //! auto connect
    const bool& autoConnect( void ) const
    { return autoConnect_; }

    //! auto connect
    ConnectionAttributes& setAutoConnect( const bool& value )
    {
        autoConnect_ = value;
        return *this;
    }

    //! tunnel attributes
    const TunnelAttributes::List& tunnelAttributes( void ) const
    { return tunnelAttributes_; }

    //! tunnel attributes
    ConnectionAttributes& setTunnelAttributes( const TunnelAttributes::List& attributes )
    {
        tunnelAttributes_ = attributes;
        return *this;
    }

    //! connection command
    QString command( void ) const;

    //! used to find attributes with same names
    class SameNameFTor
    {
        public:

        //! constructor
        SameNameFTor( const QString& name ):
            name_( name )
        {}

        //! predicate
        bool operator() (const ConnectionAttributes& attributes ) const
        { return attributes.name() == name_; }

        private:

        //! prediction
        QString name_;

    };

    private:

    //! name
    QString name_;

    //! host
    QString host_;

    //! user
    QString user_;

    //! options
    QString options_;

    //! tunnel attributes
    TunnelAttributes::List tunnelAttributes_;

    //! auto-connect
    bool autoConnect_;

};

#endif
