#ifndef ConnectionDialog_h
#define ConnectionDialog_h

// $Id: ConnectionDialog.h,v 1.9 2013/10/25 09:37:15 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "TunnelAttributesModel.h"
#include "ConnectionAttributes.h"
#include "CustomDialog.h"

#include <QCheckBox>
#include <QPushButton>

class LineEditor;
class TreeView;

//! handles ssh connection attributes
class ConnectionDialog: public CustomDialog
{

    Q_OBJECT

    public:

    //! constructor
    ConnectionDialog( QWidget* parent = 0 );

    //! destructor
    virtual ~ConnectionDialog( void )
    {}

    //! set connection attributes
    void setConnectionAttributes( const ConnectionAttributes& );

    //! get connection attributes
    ConnectionAttributes connectionAttributes( void ) const;

    protected Q_SLOTS:

    //! update button enability
    void _updateButtons( void );

    //! add
    void _add( void );

    //! edit
    void _edit( void );

    //! remove
    void _remove( void );

    private:

    //! list
    TreeView& _list( void ) const
    { return *list_; }

    //! model
    TunnelAttributesModel& _model( void )
    { return model_; }

    //! model
    const TunnelAttributesModel& _model( void ) const
    { return model_; }

    //! add button
    QPushButton& _addButton( void ) const
    { return *addButton_; }

    //! edit button
    QPushButton& _editButton( void ) const
    { return *editButton_; }

    //! remove button
    QPushButton& _removeButton( void ) const
    { return *removeButton_; }

    //! name editor
    LineEditor* nameEditor_;

    //! host
    LineEditor* hostEditor_;

    //! user
    LineEditor* userEditor_;

    //! options
    LineEditor* optionsEditor_;

    //! auto connect
    QCheckBox* autoConnect_;

    //! tunnel list
    TreeView* list_;

    //! tunnel attributes model
    TunnelAttributesModel model_;

    //! add
    QPushButton* addButton_;

    //! edit
    QPushButton* editButton_;

    //! remove
    QPushButton* removeButton_;

};

#endif
