#ifndef ConnectionObject_h
#define ConnectionObject_h

// $Id: ConnectionObject.h,v 1.15 2013/10/30 11:31:08 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ConnectionAttributes.h"
#include "Counter.h"
#include "CustomProcess.h"

#include <QAction>
#include <QBasicTimer>
#include <QObject>
#include <QTimerEvent>

//! connection widget interface
class ConnectionObject: public QObject, public Counter
{

    Q_OBJECT;

    public:

    //! constructor
    ConnectionObject( QObject* parent );

    //! destructor
    virtual ~ConnectionObject( void );

    //!@name accessors
    //@{

    //! connection attributes
    const ConnectionAttributes& connectionAttributes( void ) const
    { return attributes_; }

    //! connect
    QAction& connectAction( void ) const
    { return *connectAction_; }

    //@}

    //!@name modifiers
    //@{

    //! connection attributes
    void setConnectionAttributes( const ConnectionAttributes& attributes );

    //@}

    Q_SIGNALS:

    //! message available
    void messageAvailable( QString );

    //! log message available
    void logMessageAvailable( QString );

    //! connection status changed
    void connected( void );

    //! disconnected
    void disconnected( void );

    protected:

    //! timer
    virtual void timerEvent( QTimerEvent* );

    protected Q_SLOTS:

    //! connect
    void _toggleConnection( bool );

    //! error from process
    void _error( QProcess::ProcessError );

    //! read on-fly from process
    void _readStdout( void );

    //! read on-fly from process
    void _readStderr( void );

    //! connection close
    void _connectionClosed(  int, QProcess::ExitStatus );

    private:

    //! actions
    void _installActions( void );

    //! timer
    QBasicTimer timer_;

    //! attributes
    ConnectionAttributes attributes_;

    //! custom process
    CustomProcess* process_;

    //! stored state
    bool savedState_;

    //!@name actions
    //@{

    //! connect
    QAction* connectAction_;

    //@}

};

#endif
