#ifndef MainMenu_h
#define MainMenu_h

// $Id: MainMenu.h,v 1.15 2013/10/25 09:37:16 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ConnectionAttributes.h"
#include "Counter.h"
#include "Debug.h"

#include <QMenu>

//! application main window
class MainMenu: public QMenu, public Counter
{

    Q_OBJECT

    public:

    //! constructor;
    MainMenu( QWidget* parent = 0 );

    //! destructor
    virtual ~MainMenu( void );

    //! read connections
    void readConnections( void );

    //! return number of connections
    unsigned int connectionsCount( void ) const;

    //! auto connect
    void autoConnect( void );

    //! configuration
    QAction& configurationAction( void ) const
    { return *configureAction_; }

    Q_SIGNALS:

    //! message available
    void messageAvailable( QString );

    //! log message available
    void logMessageAvailable( QString );

    //! connection status changed
    void connectionStatusChanged( void );

    public Q_SLOTS:

    //! reconnect
    void reconnect( void );

    //! close all connections
    void closeConnections( void );

    //! new connection
    void newConnection( void );

    protected:

    //! show event
    virtual void showEvent( QShowEvent* );

    private Q_SLOTS:

    //! connection have been changed and needs to be saved to disk
    void _connectionsChanged( void );

    //! configure connections
    void _configureConnections( void );

    private:

    //! actions
    void _installActions( void );

    //! add connection
    void _addConnection( const ConnectionAttributes& );

    //! configuration action
    QAction* configureAction_;

    //! reconnection
    QAction* reconnectAction_;

    //! same connection settings
    class SameConnectionFTor
    {

        public:

        //! constructor
        SameConnectionFTor( const ConnectionAttributes& attributes ):
            attributes_( attributes )
        {}

        //! predicate
        bool operator() (const ConnectionAttributes& attributes )
        { return !attributes_.connectionSettingsChanged( attributes ); }

        private:

        //! prediction
        ConnectionAttributes attributes_;

    };


};

#endif
