#ifndef MessageQueue_h
#define MessageQueue_h

// $Id: MessageQueue.h,v 1.9 2013/10/25 09:37:16 hupereir Exp $


/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"

#include <QObject>

class MessageBox;

//! manage messages from system tray icon
class MessageQueue: public QObject, public Counter
{
    Q_OBJECT

    public:

    //! constructor
    MessageQueue( QObject* parent = 0 );

    //! destructor
    virtual ~MessageQueue( void );

    //! direction
    enum Direction {
        Ascending,
        Descending
    };

    //! direction
    void setDirection( const Direction& direction )
    { direction_ = direction; }

    //! vertical offset
    void setVerticalOffset( int value );

    public Q_SLOTS:

    //! process message
    void processMessage( QString );

    private Q_SLOTS:

    //! message box deleted
    void _messageBoxDestroyed( void );

    //! update configuration
    void _updateConfiguration( void );

    private:

    //! true if message box is valid
    bool _hasMessageBox( void ) const
    { return messageBox_; }

    //! message box
    MessageBox& _messageBox( void ) const
    { return *messageBox_; }

    //! create message box
    void _createMessageBox( void );

    //! update box geometry
    void _updateGeometry( void );

    //! vertical offset
    const int& _verticalOffset( void ) const
    { return verticalOffset_; }

    //! direction
    const Direction& _direction( void ) const
    { return direction_; }

    //! vertical offset
    int verticalOffset_;

    //! direction
    Direction direction_;

    //! message box
    MessageBox* messageBox_;

};

#endif
